testing library
Test utilities for the happy_review package.
Import this in your test files to get access to fakes and helpers for testing your Happy Review integration without mocking libraries.
import 'package:happy_review/testing.dart';
Classes
- FakeDialogAdapter
- A configurable ReviewDialogAdapter for testing.
- FakeStorageAdapter
- An in-memory ReviewStorageAdapter for testing.